# Changelog

## 1.1.0 - 2025-08-06

### Changed (2)

- Updated `list_subscribe` method `json_msg` format and response.
- Added Enum serialization in `utils.py` to handle Enum values.

## 1.0.0 - 2025-01-16

First release
